<?php

namespace Dmitry\Catalog\Http\Controllers;

use App\Http\Controllers\PublicApiController as PublicController;
use Dmitry\Catalog\Interfaces\CatalogRepositoryInterface;
use Dmitry\Catalog\Repositories\Presenter\CatalogItemTransformer;

/**
 * Pubic API controller class.
 */
class CatalogPublicApiController extends PublicController
{
    /**
     * Constructor.
     *
     * @param type \Dmitry\Catalog\Interfaces\CatalogRepositoryInterface $catalog
     *
     * @return type
     */
    public function __construct(CatalogRepositoryInterface $catalog)
    {
        $this->repository = $catalog;
        parent::__construct();
    }

    /**
     * Show catalog's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $catalogs = $this->repository
            ->setPresenter('\\Dmitry\\Catalog\\Repositories\\Presenter\\CatalogListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $catalogs['code'] = 2000;
        return response()->json($catalogs)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show catalog.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $catalog = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($catalog)) {
            $catalog         = $this->itemPresenter($module, new CatalogItemTransformer);
            $catalog['code'] = 2001;
            return response()->json($catalog)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
