<?php

namespace Dmitry\Catalog\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Dmitry\Catalog\Models\Catalog;
use Request;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Dmitry\Catalog\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot(Router $router)
    {
        parent::boot($router);

        if (Request::is('*/catalog/catalog/*')) {
            $router->bind('catalog', function ($id) {
                $catalog = $this->app->make('\Dmitry\Catalog\Interfaces\CatalogRepositoryInterface');
                return $catalog->findorNew($id);
            });
        }if (Request::is('*/catalog/categories/*')) {
            $router->bind('categories', function ($id) {
                $categories = $this->app->make('\Dmitry\Catalog\Interfaces\CategoriesRepositoryInterface');
                return $categories->findorNew($id);
            });
        }

    }

    /**
     * Define the routes for the application.
     *
     * @param \Illuminate\Routing\Router $router
     *
     * @return void
     */
    public function map(Router $router)
    {
        $router->group(['namespace' => $this->namespace], function ($router) {
            require __DIR__ . '/../Http/routes.php';
        });
    }
}
